@@ -72,7 +72,7 @@ struct _GkbPropertyBoxInfo
 
   /* Keymaps */
   GList *keymaps;              /* A list of GkbKemap pointers */
-  GtkList *list;               /* The widget displaying the keymaps */
+  GtkTreeView *list;           /* The widget displaying the keymaps */
   GkbKeymap *selected_keymap;  /* A pointer to the selected keymap */
 
   /* Hotkey Entry */
