@@ -30,6 +30,10 @@
  * USA
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <gdk/gdkx.h>
 #include <sys/stat.h>
 #include <X11/Xlib.h>
@@ -364,12 +368,8 @@ gkb_prop_create_hotkey_frame (GkbPropertyBoxInfo * pbi, GtkWidget * widget)
 static void
 prophelp_cb (GtkWidget *widget, gpointer data)
 {
-/* TODO:
-  GnomeHelpMenuEntry help_entry =
-    { "gkb_applet", "index.html#GKBAPPLET-PREFS" };
-
-  gnome_help_display (NULL, &help_entry);
-*/
+	GError *error = NULL;
+        gnome_help_display("gkb","gkbapplet-prefs",&error);
 }
 
 static void
@@ -379,7 +379,8 @@ window_response (GtkWidget *w, int response, gpointer data)
   if (response == GTK_RESPONSE_HELP)
     prophelp_cb (gkb->applet, data);
   else {
-    gtk_list_clear_items (pbi->list, 0, -1);
+    gtk_list_store_clear (GTK_LIST_STORE (gtk_tree_view_get_model 
+                          (GTK_TREE_VIEW (pbi->list))));
     g_free (pbi);
     gtk_widget_destroy (w);
   }
@@ -459,7 +460,8 @@ gkb_prop_box_destroy (GtkWidget * box, GkbPropertyBoxInfo * pbi)
    * row, so we need to clear the selection so that the
    * gkb_prop_list_selection_changed function is not reached.
    * if you know of a way to solve this, enlighten me. Chema */
-  gtk_list_clear_items (pbi->list, 0, -1);
+  gtk_list_store_clear (GTK_LIST_STORE (gtk_tree_view_get_model 
+                        (GTK_TREE_VIEW (pbi->list))));
   g_free (pbi);
 
   return FALSE;
