@@ -189,7 +189,21 @@ static gint setup_done = FALSE;
 static void about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
 	static GtkWidget *about = NULL;
-	const gchar *authors[8];
+	GdkPixbuf 	 *pixbuf;
+	GError		 *error = NULL;
+	gchar		 *file;
+	
+	static const gchar *authors[] = {
+		"John Ellis <johne@bellatlantic.net>",
+		"Martin Baulig <martin@home-of-linux.org> - ISDN",
+		NULL
+	};
+
+	const gchar *documenters[] = {
+		NULL
+	};
+
+	const gchar *translator_credits = _("translator_credits");
 
 	if (about != NULL)
 	{
@@ -198,19 +212,30 @@ static void about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbna
 		return;
 	}
 
-	authors[0] = "John Ellis <johne@bellatlantic.net>";
-	authors[1] = "Martin Baulig <martin@home-of-linux.org> - ISDN";
-	authors[2] = NULL;
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-modem.png", FALSE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, &error);
+	g_free (file);
+	
+	if (error) {
+		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+		g_error_free (error);
+	}
 
-        about = gnome_about_new ( _("Modem Lights Applet"), VERSION,
+        about = gnome_about_new ( _("Modem Lights"), VERSION,
 			"(C) 2000",
 			_("Released under the GNU general public license.\n"
 			"A modem status indicator and dialer.\n"
 			"Lights in order from the top or left are Send data and Receive data."),
 			authors,
-			NULL,
-			NULL,
-			NULL);
+			documenters,
+			strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			pixbuf);
+
+	if (pixbuf)
+		gdk_pixbuf_unref (pixbuf);
+
+	gtk_window_set_wmclass (GTK_WINDOW (about), "modem lights", "Modem Lights");
+	gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gnome-modem.png");
 	gtk_signal_connect( GTK_OBJECT(about), "destroy",
 			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
 	gtk_widget_show (about);
@@ -1402,15 +1427,12 @@ static const BonoboUIVerb modem_applet_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
-static const char modem_applet_menu_xml [] =
-	"<popup name=\"button3\">\n"
-	"   <menuitem name=\"Item 1\" verb=\"Props\" _label=\"Properties\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-	"   <menuitem name=\"Item 2\" verb=\"Help\" _label=\"Help\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-	"   <menuitem name=\"Item 3\" verb=\"About\" _label=\"About\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-	"</popup>\n";
+static void
+destroy_cb (GtkWidget *widget, gpointer data)
+{
+	gtk_timeout_remove (update_timeout_id);
+	
+}
 
 static gboolean
 modemlights_applet_fill (PanelApplet *applet)
@@ -1499,13 +1521,18 @@ modemlights_applet_fill (PanelApplet *applet)
 
 	gtk_signal_connect(GTK_OBJECT(applet),"style_set",
 		GTK_SIGNAL_FUNC(applet_style_change_cb), NULL);
+		
+	g_signal_connect (G_OBJECT (applet), "destroy",
+			  G_CALLBACK (destroy_cb), NULL);
 				
 	sizehint = panel_applet_get_size (PANEL_APPLET (applet));
 	
-	panel_applet_setup_menu (PANEL_APPLET (applet),
-				 modem_applet_menu_xml,
-				 modem_applet_menu_verbs,
-				 applet);
+	panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
+					   NULL,
+					   "GNOME_ModemlightsApplet.xml",
+					   NULL,
+					   modem_applet_menu_verbs,
+					   applet);
 				 
 	/* by now we know the geometry */
 	setup_done = TRUE;
