@@ -15,6 +15,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <libbonobo.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
@@ -27,7 +31,7 @@
 
 static const gchar *actions_menu_xml =
 	"    <placeholder name=\"ChildItem\">\n"
-	"        <menuitem name=\"Remove\" verb=\"Remove\" label=\"Remove Actions\"\n"
+	"        <menuitem name=\"Remove\" verb=\"Remove\" label=\"Remove Actions Menu\"\n"
 	"                  pixtype=\"stock\" pixname=\"gtk-close\"/>\n"
 	"        <separator/>"
 	"    </placeholder>";
@@ -51,6 +55,7 @@ typedef struct _ActionItem {
 	gchar *name;
 	gchar *path;
 	gchar *image;
+	gchar *tooltip;
 	ActionItemConstructor constructor;
 } ActionItem;
 
@@ -63,14 +68,16 @@ static void construct_show_desktop_item (GtkWidget *widget);
 static void show_desktop_cb (GtkWidget *widget, gpointer data);
 
 static ActionItem action_items[] = {
-	{ACTION_ITEM_TYPE_RUN, "Run...", "action:run",
-	 DATADIR "/pixmaps/gnome-run.png", construct_run_item},
-	{ACTION_ITEM_TYPE_LOGOUT, "Logout", "action:logout",
-	 DATADIR "/pixmaps/gnome-term-night.png", construct_logout_item},
-	{ACTION_ITEM_TYPE_LOCK, "Lock Screen", "action:lock",
-	 DATADIR "/pixmaps/gnome-lockscreen.png", construct_lock_item},
 	{ACTION_ITEM_TYPE_SHOW_DESKTOP, "Show Desktop", "action:show-desktop",
-	 DATADIR "/pixmaps/gnome-ccdesktop.png", construct_show_desktop_item}
+	 DATADIR "/pixmaps/gnome-ccdesktop.png", "Show desktop", construct_show_desktop_item}
+/*
+	{ACTION_ITEM_TYPE_RUN, "Run...", "action:run",
+	 DATADIR "/pixmaps/gnome-run.png", "Run applications, if you know the correct command to type in", construct_run_item},
+	{ACTION_ITEM_TYPE_LOGOUT, "Logout", "action:logout",
+	 DATADIR "/pixmaps/gnome-term-night.png", "Quit from the GNOME desktop", construct_logout_item},
+	{ACTION_ITEM_TYPE_LOCK, "Lock Screen", "action:lock",
+	 DATADIR "/pixmaps/gnome-lockscreen.png", "Protect your computer from unauthorized use", construct_lock_item},
+*/
 };
 
 static gint n_actions = sizeof (action_items) / sizeof (ActionItem);
@@ -90,6 +97,7 @@ panel_menu_actions_new (PanelMenu *parent)
 	actions = g_new0 (PanelMenuActions, 1);
 	entry->data = (gpointer) actions;
 	actions->actions = gtk_menu_item_new_with_label (_("Actions"));
+	add_tooltip(actions->actions, _("Actions Menu"));
 	panel_menu_common_widget_dnd_init (entry);
 	gtk_widget_show (actions->actions);
 	actions->menu = gtk_menu_new ();
@@ -149,8 +157,8 @@ panel_menu_actions_get_widget (PanelMenuEntry *entry)
 {
 	PanelMenuActions *actions;
 
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (entry->type == PANEL_MENU_TYPE_ACTIONS);
+	g_return_val_if_fail (entry != NULL, NULL);
+	g_return_val_if_fail (entry->type == PANEL_MENU_TYPE_ACTIONS, NULL);
 
 	actions = (PanelMenuActions *) entry->data;
 	return actions->actions;
@@ -170,6 +178,7 @@ construct_from_uri (gchar *uri)
 						    action_items[counter].image);
 			g_object_set_data (G_OBJECT (widget), "uri-path",
 					   action_items[counter].path);
+			add_tooltip(widget, _(action_items[counter].tooltip));
 			gtk_widget_show (widget);
 			action_items[counter].constructor (widget);
 			break;
@@ -181,10 +190,6 @@ construct_from_uri (gchar *uri)
 static void
 show_run_dialog_cb (GtkWidget *widget, gpointer data)
 {
-/*
-	Bonobo_Unknown *panel;
-	bonobo_get_object
-*/
 }
 
 static void
@@ -234,8 +239,8 @@ show_desktop_cb (GtkWidget *widget, gpointer data)
 gchar *
 panel_menu_actions_save_config (PanelMenuEntry *entry)
 {
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (entry->type == PANEL_MENU_TYPE_ACTIONS);
+	g_return_val_if_fail (entry != NULL, NULL);
+	g_return_val_if_fail (entry->type == PANEL_MENU_TYPE_ACTIONS, NULL);
 
 	return g_strdup ("actions");
 }
